==> JDFLibJ-2.1.5.90-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/jdftoxjdf/WalkPhaseTimeAudit.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2015 The International Cooperation for the Integration of 
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of 
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of 
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration 
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software 
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG 
 * copyright (c) 1999-2001, Agfa-Gevaert N.V. 
 *  
 * For more information on The International Cooperation for the 
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *  
 * 
 */
package org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFDoc;
import org.cip4.jdflib.core.JDFResourceLink;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.core.VElement;
import org.cip4.jdflib.datatypes.JDFAttributeMap;
import org.cip4.jdflib.datatypes.VJDFAttributeMap;
import org.cip4.jdflib.extensions.PartitionHelper;
import org.cip4.jdflib.extensions.XJDF20;
import org.cip4.jdflib.jmf.JDFJMF;
import org.cip4.jdflib.resource.JDFPhaseTime;

/**
 * 
 * @author Rainer Prosi, Heidelberger Druckmaschinen
 * 
 */
public class WalkPhaseTimeAudit extends WalkAudit
{

	/**
	 * 
	 */
	public WalkPhaseTimeAudit()
	{
		super();
	}

	/**
	 * @param jdf
	 * @param xjdf
	 * @return true if must continue
	 */
	@Override
	public KElement walk(final KElement jdf, final KElement xjdf)
	{
		final JDFPhaseTime pt = (JDFPhaseTime) jdf;
		JDFJMF jmf = pt.toSignalJMF();
		jmf.appendAnchor(null);
		KElement xjmf = new JDFDoc(XJDF20.rootJMF).getRoot();
		jdfToXJDF.walkTree(jmf, xjmf);
		KElement signalxjmf = xjmf.getFirstChildElement();
		signalxjmf.removeChild(ElementName.STATUSQUPARAMS, null, 0);
		final VElement vL = pt.getLinkVector();
		if (vL != null)
		{
			for (KElement e : vL)
			{
				e.deleteNode();
			}
		}
		KElement ret = super.walk(jdf, xjdf);
		ret.removeChildren(null, null, null);
		ret.copyElements(signalxjmf.getChildElementVector(null, null), null);
		signalxjmf.removeAttribute(AttributeName.ID);
		ret.removeAttribute(AttributeName.TIMESTAMP);
		ret.setAttributes(signalxjmf);
		jdf.removeChildren(null, null, null);
		ret.renameElement("AuditStatus", null);
		return ret;
	}

	/**
	 * @param xjdf
	 * @return true if must continue
	 */
	private KElement oldwalk(final KElement jdf, final KElement xjdf)
	{
		final JDFPhaseTime pt = (JDFPhaseTime) jdf;
		final VElement vL = pt.getLinkVector();
		final VElement phaseAmounts = new VElement();
		VJDFAttributeMap partsPhaseTime = pt.getPartMapVector();
		if (vL != null)
		{
			for (KElement e : vL)
			{
				final JDFResourceLink rl = (JDFResourceLink) e;
				VJDFAttributeMap partsResLink = rl.getPartMapVector();
				if (partsResLink == null)
				{
					if (partsPhaseTime != null)
					{
						partsResLink = partsPhaseTime.clone();
					}
					else
					{
						partsResLink = new VJDFAttributeMap((JDFAttributeMap) null);
					}
				}

				final VElement vR = setResource(null, rl.getLinkRoot(), jdfToXJDF.newRoot);
				final KElement phaseAmount = xjdf.appendElement("PhaseAmount");
				JDFAttributeMap commonMap = partsResLink.getCommonMap();
				for (KElement res : vR)
				{
					VJDFAttributeMap resParts = new PartitionHelper(res).getPartMapVector();
					if (resParts.overlapsMap(partsResLink))
					{
						phaseAmount.appendAttribute("rRef", res.getAttribute(AttributeName.ID), null, " ", true);
						setAmountPool(rl, phaseAmount, commonMap);
						for (String extension : new String[] { "", "Good", "Waste" })
						{
							phaseAmount.removeAttribute(AttributeName.AMOUNT + extension);
							phaseAmount.renameAttribute(AttributeName.ACTUALAMOUNT + extension, AttributeName.AMOUNT + extension, null, null);
						}
					}
				}
				rl.deleteNode();
				phaseAmounts.add(phaseAmount);
			}
		}

		final KElement x2 = super.walk(jdf, xjdf); // copy anything but the links (see deleteNode above...)
		if (x2 != null)
		{
			for (int i = 0; i < phaseAmounts.size(); i++)
			{
				x2.moveElement(phaseAmounts.get(i), null);
			}
		}
		return x2;
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#matches(org.cip4.jdflib.core.KElement)
	 * @param toCheck
	 * @return true if it matches
	 */
	@Override
	public boolean matches(final KElement toCheck)
	{
		return !jdfToXJDF.isRetainAll() && toCheck instanceof JDFPhaseTime;
	}

	/**
	 * remove all stuff that is now in the JobPhases
	 * @see org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf.WalkJDFElement#removeUnused(org.cip4.jdflib.core.KElement)
	 */
	@Override
	protected void removeUnused(KElement newRootP)
	{
		newRootP.removeAttribute(AttributeName.STATUS);
		newRootP.removeAttribute(AttributeName.STATUSDETAILS);
		newRootP.removeAttribute(AttributeName.STARTTIME);
		newRootP.removeAttribute(AttributeName.START);
		newRootP.removeAttribute(AttributeName.END);
		newRootP.removeAttribute(AttributeName.QUEUEENTRYID);
		super.removeUnused(newRootP);
	}
}

==> JDFLibJ-2.1.7.30-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/jdftoxjdf/WalkPhaseTimeAudit.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2015 The International Cooperation for the Integration of 
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of 
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of 
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration 
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software 
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG 
 * copyright (c) 1999-2001, Agfa-Gevaert N.V. 
 *  
 * For more information on The International Cooperation for the 
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *  
 * 
 */
package org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFDoc;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.core.VElement;
import org.cip4.jdflib.core.VString;
import org.cip4.jdflib.datatypes.JDFAttributeMap;
import org.cip4.jdflib.extensions.XJDFConstants;
import org.cip4.jdflib.jmf.JDFJMF;
import org.cip4.jdflib.resource.JDFPhaseTime;

/**
 * 
 * @author Rainer Prosi, Heidelberger Druckmaschinen
 * 
 */
public class WalkPhaseTimeAudit extends WalkAudit
{

	/**
	 * 
	 */
	public WalkPhaseTimeAudit()
	{
		super();
	}

	/**
	 * @param jdf
	 * @param xjdf
	 * @return true if must continue
	 */
	@Override
	public KElement walk(final KElement jdf, final KElement xjdf)
	{
		final JDFPhaseTime pt = (JDFPhaseTime) jdf;
		JDFJMF jmf = pt.toSignalJMF();
		jmf.appendAnchor(null);
		KElement xjmf = new JDFDoc(XJDFConstants.XJMF).getRoot();
		jdfToXJDF.walkTree(jmf, xjmf);
		KElement signalxjmf = xjmf.getFirstChildElement();
		signalxjmf.removeChild(ElementName.STATUSQUPARAMS, null, 0);
		final VElement vL = pt.getLinkVector();
		if (vL != null)
		{
			for (KElement e : vL)
			{
				e.deleteNode();
			}
		}
		KElement ret = super.walk(jdf, xjdf);
		ret.removeChildren(null, null, null);
		ret.copyElements(signalxjmf.getChildElementVector(null, null), null);
		signalxjmf.removeAttribute(AttributeName.ID);
		ret.removeAttribute(AttributeName.TIMESTAMP);
		ret.setAttributes(signalxjmf);
		jdf.removeChildren(null, null, null);
		return ret;
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#matches(org.cip4.jdflib.core.KElement)
	 * @param toCheck
	 * @return true if it matches
	 */
	@Override
	public boolean matches(final KElement toCheck)
	{
		return !jdfToXJDF.isRetainAll() && toCheck instanceof JDFPhaseTime;
	}

	/**
	 * @see org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf.WalkElement#getXJDFName(org.cip4.jdflib.core.KElement)
	 */
	@Override
	protected String getXJDFName(KElement jdf)
	{
		return "AuditStatus";
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#getElementNames()
	 */
	@Override
	public VString getElementNames()
	{
		return VString.getVString(ElementName.PHASETIME, null);
	}

	/**
	 * @see org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf.WalkJDFSubElement#updateAttributes(org.cip4.jdflib.datatypes.JDFAttributeMap)
	 */
	@Override
	protected void updateAttributes(JDFAttributeMap map)
	{
		map.remove(AttributeName.STATUS);
		map.remove(AttributeName.STATUSDETAILS);
		map.remove(AttributeName.STARTTIME);
		map.remove(AttributeName.START);
		map.remove(AttributeName.END);
		map.remove(AttributeName.QUEUEENTRYID);
		super.updateAttributes(map);
	}
}
